@@ -1,5 +1,5 @@
 package Text::Password::CoreCrypt;
-our $VERSION = "0.11";
+our $VERSION = "0.12";
 
 use 5.8.8;
 use Moose;
@@ -20,7 +20,7 @@ no Moose;
 
 use Carp;
 my @ascii = (
-    qw| ! " # $ % & ' ( ) * + , - . / |,
+    '!', '"', '#', qw| $ % & ' ( ) * + |, ',', qw| - . / |,
     0 .. 9, qw( : ; < = > ? @ ),
     'A'..'Z', qw( [ \ ] ^ _ ` ), # to void syntax highlighting -> `
     'a'..'z', qw( { | } ~ ),
@@ -127,7 +127,7 @@ sub encrypt {
     my $min = $self->minimum();
     croak __PACKAGE__ ." requires at least $min length" if length $input < $min;
      die __PACKAGE__. " doesn't allow any Wide Characters or white spaces\n"
-    if $input !~ /[!-~]/ or $input =~ /\s/;
+    if $input =~ /[^!-~]/ or $input =~ /\s/;
     carp __PACKAGE__ . " ignores the password with over 8bytes" unless $input =~ /^[!-~]{8}$/;
 
     my $encrypt;
