@@ -1,5 +1,5 @@
 package Text::Password::SHA;
-our $VERSION = "0.11";
+our $VERSION = "0.12";
 
 use Moose;
 extends 'Text::Password::MD5';
@@ -99,12 +99,12 @@ override 'encrypt' => sub {
     my $min = $self->minimum();
     croak __PACKAGE__ ." requires at least $min length" if length $input < $min;
      die __PACKAGE__. " doesn't allow any Wide Characters or white spaces\n"
-    if $input !~ /[!-~]/ or $input =~ /\s/;
+    if $input =~ /[^!-~]/ or $input =~ /\s/;
 
-    my $salt;
-    do{ $salt = shift || $self->nonce() } while( $salt =~ /\$/ );
-
-    return Crypt::Passwd::XS::unix_sha512_crypt( $input, $salt );
+    my $hash;
+     do{ $hash = Crypt::Passwd::XS::unix_sha512_crypt( $input, $self->nonce(8) ) }
+    until( $hash =~ /^\$6\$[!-~]{1,8}\$[!-~]{86}$/ );
+    return $hash;
 };
 
 =head3 generate($length)
